Learn R Programming

ordiBreadth (version 1.0)

hyp.ordi.breadth: hyp.ordi.breadth

Description

Calculates the diet breadth of a hypothetical herbivore placed in ordination space.

Usage

hyp.ordi.breadth(dat, grouping, dist.method = "jaccard", distance = FALSE)

Arguments

dat
A matrix of diet associations. Rows are herbivores and columns are diet items.
grouping
a vector of ones and zeros or TRUE and FALSE indicting diet items of hypothetical herbivore
dist.method
Dissimilarity index passed on to vegdist in the vegan package
distance
a logical indicating whether to return distance of hypothetical herbivore centroid to plants used in PCoA space and the coordinates of the centroid in PCoA space

Value

tot.breadth
Ordinated host breadth of hypothetical herbivore
distances
Distance from centroid to diet items in PCoA space
centroid
Coordinates of the centroid of hypothetical herbivore

References

Fordyce, J.A., C.C. Nice, C.A. Hamm, & M.L. Forister. Quantifying diet breadth through ordination of host association. Ecology

Examples

Run this code
testdata<-	
	c(		
			0,0,0,0,1,0,0,0,0,0,#1
			0,0,0,0,0,0,1,1,0,0,#2
			1,1,1,0,0,0,0,0,0,0,#3
			0,0,0,0,1,1,0,1,0,1,#4
			1,1,1,0,0,0,1,0,0,0,#4
			1,1,0,0,1,0,1,0,0,0,#4
			0,0,0,1,0,0,1,0,1,1,#4
			1,0,1,0,1,1,0,0,0,1, #5
			1,1,0,0,1,0,0,1,1,1,#6
			1,1,1,0,1,1,0,1,1,1) #8


dat<-array(dim=c(10,10),data=testdata)
dat<-t(dat)
colnames(dat)<-paste("",LETTERS[1:10],sep="")
rownames(dat)<-paste("bug",1:10,sep="")

group<-c(TRUE,TRUE,TRUE,FALSE,FALSE,FALSE,FALSE,FALSE,FALSE,FALSE)
hyp.ordi.breadth(dat,group)
hyp.ordi.breadth(dat,group,distance=TRUE)

group<-c(1,1,1,1,1,1,1,1,1,1)
hyp.ordi.breadth(dat,group)#extreme generalist
hyp.ordi.breadth(dat,group,distance=TRUE)

Run the code above in your browser using DataLab