Learn R Programming

ordiBreadth (version 1.0)

ordi.focal.drop: ordi.focal.drop

Description

This function computes the ordinated host breadth based on ordination where each herbivore is excluded from the ordination.

Usage

ordi.focal.drop(dat, dist.method = "jaccard")

Arguments

dat
A matrix of diet associations. Rows are herbivores and columns are diet items.
dist.method
Dissimilarity index passed on to vegdist in the vegan package.

Value

A list containing the following:
species
Name of herbivore species (row name of dat
ODB
Ordinated diet breadth
ODB.scaled
Scaled ordinated diet breadth
focal.distances
Distance to each diet item from herbivore centroid based on ordination excluding focal herbivore
focal.breadth
Ordinated diet breadth of herbivore based on ordination where focal herbivore is excluded
focal.scale.factor
The ordinated diet breadth of an extreme generalist in the ordinated space when focal herbivore is excluded from the ordination
focal.scale.breadth
Scaled ordinated diet breadth of herbivore based on ordination where focal herbivore is excluded

References

Fordyce, J.A., C.C. Nice, C.A. Hamm, & M.L. Forister. Quantifying diet breadth through ordination of host association. Ecology

Examples

Run this code
testdata<-	
	c(		
			0,0,0,0,1,0,0,0,0,0,
			0,0,0,0,0,0,1,1,0,0,
			1,1,1,0,0,0,0,0,0,0,
			0,0,0,0,1,1,0,1,0,1,
			1,1,1,0,0,0,1,0,0,0,
			1,1,0,0,1,0,1,0,0,0,
			0,0,0,1,0,0,1,0,1,1,
			1,0,1,0,1,1,0,0,0,1, 
			1,1,0,0,1,0,0,1,1,1,
			1,1,1,0,1,1,0,1,1,1) 


dat<-array(dim=c(10,10),data=testdata)
dat<-t(dat)
colnames(dat)<-paste("",LETTERS[1:10],sep="")
rownames(dat)<-paste("bug",1:10,sep="")


ordi.focal.drop(dat)

Run the code above in your browser using DataLab