Learn R Programming

ordiBreadth (version 1.0)

ordiBreadth-package: Calculates ordinated diet breadth.

Description

Calculates ordinated diet breadth and provides plotting functions.

Arguments

Details

Package:
ordiBreadth
Type:
Package
Version:
1.0
Date:
2015-08-07
License:
GPL 3.0
Users provide a matrix of host associations, where rows are consumers (e.g., heribivores) and columns are resources (e.g., plants). The function ordi.breadth calculates the ordinated breadth for all consumers in the matrix and summary.hbreadth summarizes the output and dist.group.plot can be used for visualization.

References

Fordyce, J.A., C.C. Nice, C.A. Hamm, & M.L. Forister. Quantifying diet breadth through ordination of host association. Ecology